import { ChevronRight, Book, Sparkles } from "lucide-react";
import { Button } from "@traken-ui/react";

function ModernHeroSection() {

  return (
    <div className="relative bg-gray-900 text-white py-20 md:py-32 px-4 lg:py-60 overflow-hidden">
      <div className="absolute inset-0 bg-gradient-to-br from-[#09171D] via-[#09242D] to-[#09242D">
        <div className="absolute inset-0 opacity-10">
          <div className="absolute top-0 left-0 w-full h-full bg-grid-pattern transform rotate-12 scale-150"></div>
        </div>
      </div>

      <div className="absolute top-10 left-10 w-64 h-64 bg-blue-500 rounded-full mix-blend-multiply filter blur-5xl opacity-10 animate-blob"></div>
      <div className="absolute bottom-10 right-10 w-64 h-64 bg-purple-500 rounded-full mix-blend-multiply filter blur-5xl opacity-10 animate-blob animation-delay-2000"></div>
      <div className="absolute bottom-32 left-32 w-64 h-64 bg-indigo-500 rounded-full mix-blend-multiply filter blur-5xl opacity-10 animate-blob animation-delay-4000"></div>

      <div className="container mx-auto max-w-6xl relative z-10">
        <div
          className={`transition-all duration-1000 transform`}
        >
          <div className="flex justify-center mb-6">
            <Button
              variant="ghost"
              className="inline-flex items-center px-3 py-1 rounded-full text-sm font-medium bg-gray-800 text-[#3EBCB2] border border-gray-700"
            >
              <Sparkles size={16} className="mr-2" />
              <span>NextGen Component Library</span>
            </Button>
          </div>

          <h1 className="text-4xl md:text-6xl lg:text-7xl font-bold mb-6 text-center bg-clip-text text-transparent bg-gradient-to-r from-blue-400 via-[#3EBCB2] to-indigo-400">
            Welcome to Traken UI
          </h1>

          <p className="text-lg md:text-xl text-gray-300 mb-12 text-center max-w-2xl mx-auto">
            Traken UI is a modern React component library offering sleek,
            flexible, and easy-to-use components for fast, consistent UI
            development.
          </p>

          <div className="flex flex-col gap-4 md:flex-row w-full justify-center items-center sm:flex-row sm:space-y-0 sm:space-x-2">
            <Button
              variant="ghost"
              className={`w-full sm:max-w-fit group flex items-center justify-center bg-gradient-to-r from-[#2F7086] to-[#2F748C] hover:from-[#2F7086] hover:to-[#2F7086] text-white font-bold py-3 px-6 rounded-lg transition-all duration-300 shadow-sm hover:shadow-blue-500/25 cursor-pointer`}
              style={{ transitionDelay: "200ms" }}
            >
              Get Started{" "}
              <ChevronRight
                size={20}
                className="ml-2 transform group-hover:translate-x-1 transition-transform"
              />
            </Button>

            <Button
              variant="ghost"
              className={`w-full sm:max-w-fit group flex items-center justify-center   text-white font-bold py-3 px-6 border border-gray-400 rounded-lg transition-all duration-300 hover:border-gray-600 cursor-pointer`}
              style={{ transitionDelay: "200ms" }}
            >
              {" "}
              <Book size={20} className="mr-2" />
              Documentation
            </Button>
          </div>
        </div>
      </div>

      {/* Floating Badges */}
      <div className="container mx-auto max-w-6xl relative">
        <div
          className={` absolute top-10 right-10 bg-gray-800 p-3 rounded-lg border border-gray-700 shadow-xl transition-all duration-1000 transform`}
        >
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 rounded-full bg-green-400"></div>
            <span className="text-xs text-gray-300">Online Services</span>
          </div>
        </div>

        <div
          className={` absolute bottom-10 left-10 bg-gray-800 p-3 rounded-lg border border-gray-700 shadow-xl transition-all duration-1000 transform`}
        >
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 rounded-full bg-blue-400"></div>
            <span className="text-xs text-gray-300">24/7 Support</span>
          </div>
        </div>
      </div>
    </div>
  );
}

export default ModernHeroSection;
